Processor.App.Pipeline.pipeline.ProcessorPipeline — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.Pipeline.pipeline.ProcessorPipeline

class Processor.App.Pipeline.pipeline.ProcessorPipeline(router: Router, downloader: Downloader, outstreamer: OutStreamer)
  __init__(router: Router, downloader: Downloader, outstreamer: OutStreamer)

  Methods

  `__init__`(router, downloader, outstreamer) |
  `process_domain_record`(domain_record) |